@@ -1,4 +1,3 @@
-#!/usr/bin/perl -w -T
 # -*- perl -*-
 
 # Net::FTPServer A Perl FTP Server
@@ -19,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: DirHandle.pm,v 1.9 2001/10/10 10:05:36 rich Exp $
+# $Id: DirHandle.pm,v 1.13 2002/12/28 02:31:04 rbrown Exp $
 
 =pod
 
@@ -43,10 +42,8 @@ package Net::FTPServer::Full::DirHandle;
 
 use strict;
 
-# Some magic which is required by CPAN. This is not the real version
-# number. If you want that, have a look at FTPServer::VERSION.
 use vars qw($VERSION);
-$VERSION = '1.0';
+( $VERSION ) = '$Revision: 1.13 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use IO::Dir;
 use Carp qw(confess);
@@ -158,12 +155,9 @@ sub list
 
     foreach $file (@filenames)
       {
-	my $handle
-	  = -d "$self->{_pathname}$file"
-	    ? Net::FTPServer::Full::DirHandle->new ($self->{ftps}, $self->{_pathname} . $file . "/")
-	    : Net::FTPServer::Full::FileHandle->new ($self->{ftps}, $self->{_pathname} . $file);
-
-	push @array, [ $file, $handle ];
+        if (my $handle = $self->get($file)) {
+          push @array, [ $file, $handle ];
+        }
       }
 
     return \@array;
@@ -308,7 +302,11 @@ sub delete
   {
     my $self = shift;
 
-    rmdir $self->{_pathname} or return -1;
+    # Darwin / Mac OS X cannot delete a directory with a trailing "/", so
+    # remove it first (thanks Luis Mun\~oz for fixing this).
+    my $path = $self->{pathname};
+    $path =~ s,/+$,, if $path ne "/";
+    rmdir $path or return -1;
 
     return 0;
   }
